hdx.facades package
===================

Submodules
----------

hdx.facades.keyword\_arguments module
-------------------------------------

.. automodule:: hdx.facades.keyword_arguments
   :members:
   :undoc-members:
   :show-inheritance:

hdx.facades.simple module
-------------------------

.. automodule:: hdx.facades.simple
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: hdx.facades
   :members:
   :undoc-members:
   :show-inheritance:
